==> CodeMirror-0.1.3.zip: CodeMirror/action.defaultadmin.php <==
<?php


if (!isset($gCms)) exit;

if (!$this->CheckPermission('Modify Site Preferences')) {
  echo $this->ShowErrors($this->Lang('needpermission', array('Modify Site Preferences')));
  return;
}

echo $this->StartTabHeaders();
echo $this->SetTabHeader("settings",$this->Lang("settingstab"));

echo $this->SetTabHeader("htmltest",$this->Lang("htmltest"));
echo $this->SetTabHeader("csstest",$this->Lang("csstest"));
echo $this->SetTabHeader("phptest",$this->Lang("phptest"));

echo $this->EndTabHeaders();
echo $this->StartTabContent();


echo $this->StartTab("settings");
$this->smarty->assign('startform', $this->CreateFormStart($id, 'savesettings', $returnid));
$this->smarty->assign('endform', $this->CreateFormEnd());

$this->smarty->assign('showlinenumberstext', $this->Lang("showlinenumbers"));
$this->smarty->assign('showlinenumbersinput', $this->CreateInputCheckbox($id,"showlinenumbers",1,$this->GetPreference("showlinenumbers",1)));

$this->smarty->assign('textwrappingtext', $this->Lang("textwrapping"));
$this->smarty->assign('textwrappinginput', $this->CreateInputCheckbox($id,"textwrapping",1,$this->GetPreference("textwrapping",1)));

$this->smarty->assign('useautocompletetext', $this->Lang("useautocomplete"));
$this->smarty->assign('useautocompleteinput', $this->CreateInputCheckbox($id,"useautocomplete",1,$this->GetPreference("useautocomplete",1)));

$this->smarty->assign('submit', $this->CreateInputSubmit($id, 'submit', $this->Lang('savesettings')));

echo $this->ProcessTemplate('settings.tpl');

echo $this->EndTab();

echo $this->StartTab("htmltest");
$content="
<html>
  <head>
    <title>Testing html-syntax</title>
  </head>
  <body>
    And doing absolutely nothing else
  </body>
</html> 
";
echo $this->CreateFormStart($id,"defaultadmin");
echo $this->CreateTextArea(false,$id,$content,"testarea1",'','','','','60','10','CodeMirror','html');

echo $this->CreateFormEnd();
echo $this->EndTab();

echo $this->StartTab("csstest");
$content="
.testcss {
  font-weight:bold;
  height: 10px;
} 
";
echo $this->CreateFormStart($id,"defaultadmin");
echo $this->CreateTextArea(false,$id,$content,"testarea2",'','','','','60','10','CodeMirror','css');

echo $this->CreateFormEnd();

echo $this->EndTab();

echo $this->StartTab("phptest");
$content="
<?php
  function testPHP(\$someparam) {
    echo 'Do you think this looks nice?';
  }
?>
";
echo $this->CreateFormStart($id,"defaultadmin");
echo $this->CreateTextArea(false,$id,$content,"testarea3",'','','','','60','10','CodeMirror','php');
echo $this->CreateFormEnd();

echo $this->EndTabContent();


/*

echo "<h3>".$this->Lang("testarea").":</h3>";

$content="
<html>
  <head>
    <title>Testing html-syntax</title>
  </head>
  <body>
    And doing absolutely nothing else
  </body>
</html> 
";
echo $this->CreateFormStart($id,"defaultadmin");
echo $this->CreateTextArea(false,$id,$content,"testarea",'','','','','','','CodeMirror','html');
echo $this->CreateFormEnd();
 
echo $this->EndTab();
 */

?>

==> CodeMirror-0.1.5.zip: CodeMirror/action.defaultadmin.php <==
<?php


if (!isset($gCms)) exit;

if (!$this->CheckPermission('Modify Site Preferences')) {
  echo $this->ShowErrors($this->Lang('needpermission', array('Modify Site Preferences')));
  return;
}

if (isset($params["examplesyntax"])) {
  $this->SetPreference("examplesyntax",$params["examplesyntax"]);
}

echo $this->StartTabHeaders();
echo $this->SetTabHeader("settings",$this->Lang("settingstab"));

echo $this->EndTabHeaders();
echo $this->StartTabContent();


echo $this->StartTab("settings");
$this->smarty->assign('startform', $this->CreateFormStart($id, 'savesettings', $returnid));
$this->smarty->assign('endform', $this->CreateFormEnd());

$this->smarty->assign('showlinenumberstext', $this->Lang("showlinenumbers"));
$this->smarty->assign('showlinenumbersinput', $this->CreateInputCheckbox($id,"showlinenumbers",1,$this->GetPreference("showlinenumbers",1)));

$this->smarty->assign('textwrappingtext', $this->Lang("textwrapping"));
$this->smarty->assign('textwrappinginput', $this->CreateInputCheckbox($id,"textwrapping",1,$this->GetPreference("textwrapping",1)));

$this->smarty->assign('useautocompletetext', $this->Lang("useautocomplete"));
$this->smarty->assign('useautocompleteinput', $this->CreateInputCheckbox($id,"useautocomplete",1,$this->GetPreference("useautocomplete",1)));

$this->smarty->assign('submit', $this->CreateInputSubmit($id, 'submit', $this->Lang('savesettings')));

echo $this->ProcessTemplate('settings.tpl');

echo $this->EndTab();
echo $this->EndTabContent();

$content="";
switch ($this->GetPreference("examplesyntax","html")) {
  case "html" : {
    $content="
<html>
  <head>
    <title>Testing html-syntax</title>
  </head>
  <body>
    And doing absolutely nothing else
  </body>
</html>
";
  break;
  }
  case "css" : {
    $content="
.testcss {
  font-weight:bold;
  height: 10px;
}
";
  break;
  }
  case "php" : {
    $content="
<?php
  function testPHP(\$someparam) {
    echo 'Do you think this looks nice?';
  }
?>
";
  break;
  }
  case "js" : {
    $content='
function myjsfuntion(params) {
  var msg = "This javascript is fantastic!"
  for (var i=0; i<9999; i++) {
    alert(msg)
    /*This mus be the most annoying function ever!*/
  }
  return true
}
';
  break;
  }
}

echo $this->CreateFormStart($id,"defaultadmin");
echo $this->Lang("examplesyntax").": ";
$syntaxes=array($this->Lang("htmltest")=>"html",$this->Lang("csstest")=>"css",$this->Lang("phptest")=>"php",$this->Lang("jstest")=>"js");
echo $this->CreateInputDropdown($id,"examplesyntax",$syntaxes,-1,$this->GetPreference("examplesyntax","html"));
echo $this->CreateInputSubmit($id,"examplesubmit",$this->Lang("change"));
echo "<br/>";
echo $this->CreateTextArea(false,$id,$content,"testarea1",'','','','','','','CodeMirror',$this->GetPreference("examplesyntax","html"));
echo $this->CreateFormEnd();





?>
